package com.steerinfo.dil.controller;

import com.steerinfo.dil.service.impl.StatisticalReportImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @ author    :TXF
 * @ time      :2021/12/14 18:05
 */

@RestController
@RequestMapping("/${api.version}/statisticalReport")
public class StatisticalReportController extends BaseRESTfulController {

    @Autowired
    StatisticalReportImpl statisticalReportService;

    @Autowired
    ColumnDataUtil columnDataUtil;

    private final SimpleDateFormat sdfDate = new SimpleDateFormat("yyyy-MM-dd");

    private final SimpleDateFormat sdfDateTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
    @ApiOperation(value="查询辅料燃料统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(220)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getRLFLReport")
    public RESTfulResult getRLFLReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               String startTime,
                                               String endTime,
                                               Integer orderType,
                                               String con
    ){
        mapValue.put("orderTypee", orderType);
        if (con!=null && !"null".equals(con) && !"".equals(con)){
            mapValue.put("con",con);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getRLFLReport(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null,report);
        return success(pageList);
    }


    @ApiOperation(value="查询销售统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(423)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllSaleReport")
    public RESTfulResult getAllSaleReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                       Integer apiId,
                                       Integer pageNum,
                                       Integer pageSize,
                                       String startTime,
                                       String endTime,
                                       String carrierSsoId,
                                          Integer orderType,
                                          Integer shipperId,
                                          String receiveName,
                                          String materialName,
                                          String wareHouse
    ){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        if(carrierSsoId != null){
            if(!"null".equals(carrierSsoId)){
                mapValue.put("carrierSsoId", carrierSsoId);
            }
        }
        if (receiveName != null && !"null".equals(receiveName)) {
            mapValue.put("receivName","%" + receiveName + "%");
        }
        if (materialName != null && !"".equals(materialName) && !"null".equals(materialName)) {
            mapValue.put("remark","%" + materialName + "%");
        }
        if (wareHouse != null && !"".equals(wareHouse) && !"null".equals(wareHouse)) {
            mapValue.put("wareHouse","%" + wareHouse + "%");
        }
        mapValue.put("orderTypee",orderType);
        mapValue.put("shipperId",shipperId);
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getAllSaleReport(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData5(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询销售统计报表筛选过后的总净重")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(423)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllSaleReportTotal")
    public RESTfulResult getAllSaleReportTotal(@RequestBody(required=false) Map<String,Object> mapValue,
                                          String startTime,
                                          String endTime,
                                          String carrierSsoId
    ){
        if(carrierSsoId != null){
            if(!"null".equals(carrierSsoId)){
                mapValue.put("carrierSsoId", carrierSsoId);
            }
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        List<Map<String, Object>> allReport =  statisticalReportService.getAllSaleReportNum(mapValue);
        //获取销售统计报表筛选过后的总净重
        BigDecimal AllResultNetWeight = new BigDecimal(0);
        for (Map<String, Object> stringObjectMap : allReport) {
            if(stringObjectMap.get("resultNetWeight")!=null) {
                AllResultNetWeight = AllResultNetWeight.add(new BigDecimal(stringObjectMap.get("resultNetWeight").toString()));
            }
        }
        return success(AllResultNetWeight);
    }

    @ApiOperation(value="查询零星物资进厂统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(424)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getSporadicSuppliesReport1")
    public RESTfulResult getSporadicSuppliesReport1(@RequestBody(required=false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          String startTime,
                                          String endTime,
                                          String carrierSsoId,
                                          String userId, String userIds, String con, Integer orderType
    ){
        if(carrierSsoId != null) {
            if (!"null".equals(carrierSsoId)) {
                mapValue.put("carrierSsoId", carrierSsoId);
            }
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        if (userId!=null){
            mapValue.put("userId",userId);
        }
        if (orderType!=null){
            mapValue.put("orderType",orderType);
        }
        if (userIds!=null){
            mapValue.put("userIds",userIds);
        }
        if (con!=null&&!"null".equals(con)){
            mapValue.put("con","%"+con+"%");
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getSporadicSuppliesReport1(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData4(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询零星物资出厂统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(425)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getSporadicSuppliesReport2")
    public RESTfulResult getSporadicSuppliesReport2(@RequestBody(required=false) Map<String,Object> mapValue,
                                                   Integer apiId,
                                                   Integer pageNum,
                                                   Integer pageSize,
                                                   String startTime,
                                                   String endTime,
                                                   String carrierSsoId,
                                                    String userId,
                                                    String userIds,
                                                    String con,
                                                    Integer orderType
    ){
        if(carrierSsoId != null){
            if(!"null".equals(carrierSsoId)){
                mapValue.put("carrierSsoId", carrierSsoId);
            }
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        if (con!=null&&!"null".equals(con)){
            mapValue.put("con","%"+con+"%");
        }
        if (userId!=null){
            mapValue.put("userId",userId);
        }
        if (orderType!=null){
            mapValue.put("orderType",orderType);
        }
        if (userIds!=null){
            mapValue.put("userIds",userIds);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getSporadicSuppliesReport2(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData4(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询采购内转统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getPurInwardReport")
    public RESTfulResult getPurInwardReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                                    Integer apiId,
                                                    Integer pageNum,
                                                    Integer pageSize,
                                                    String startTime,
                                                    String endTime
    ){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getPurInwardReport(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询零星内转统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getLXInwardReport")
    public RESTfulResult getLXInwardReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                            Integer apiId,
                                            Integer pageNum,
                                            Integer pageSize,
                                            String startTime,
                                            String endTime,
                                           String con
    ){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        if(con != null && !"null".equals(con)){
            mapValue.put("con","%" + con + "%");
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getLXInwardReport(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询内转统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getInwardReport")
    public RESTfulResult getInwardReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                            Integer apiId,
                                            Integer pageNum,
                                            Integer pageSize,
                                            String startTime,
                                            String endTime
    ){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getInwardReport(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询该组织机构下的销售统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "486", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getSaleOrderList")
    public RESTfulResult getSaleOrderList(@RequestBody(required=false) Map<String,Object> mapValue,
                                         Integer apiId,
                                         Integer pageNum,
                                         Integer pageSize,
                                         String startTime,
                                         String endTime,
                                         String orgCode,
                                         String isPage,
                                          String index
    ){
         if (orgCode!=null&&!"null".equals(orgCode)){
             mapValue.put("orgCode",orgCode);
         }
        if (index!=null&&!"null".equals(index)){
            mapValue.put("index",index);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        if("yes".equals(isPage)){
            return success(statisticalReportService.getSaleOrderList(mapValue));
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getSaleOrderList(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData4(apiId, null, report);
        return success(pageList);
    }


    @ApiOperation(value="查询该组织机构下的采购统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "486", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getPurchaseOrderList")
    public RESTfulResult getPurchaseOrderList(@RequestBody(required=false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          String startTime,
                                          String endTime,
                                          String orgCode,
                                              String isPage,
                                              String index
    ){

        if (orgCode!=null&&!"null".equals(orgCode)){
            mapValue.put("orgCode",orgCode);
        }
        if (index!=null&&!"null".equals(index)){
            mapValue.put("index",index);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        if ("yes".equals(isPage)){
            return success(statisticalReportService.getPurchaseOrderList(mapValue));
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getPurchaseOrderList(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData4(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询该组织机构下的采购内转统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "s", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getPurchaseInwardList")
    public RESTfulResult getInwardList(@RequestBody(required=false) Map<String,Object> mapValue,
                                              Integer apiId,
                                              Integer pageNum,
                                              Integer pageSize,
                                              String startTime,
                                              String endTime,
                                              String orgCode,
                                                String isPage,
                                             String index
    ){
        if (index!=null&&!"null".equals(index)){
            mapValue.put("index",index);
        }
        if (orgCode!=null&&!"null".equals(orgCode)){
            mapValue.put("orgCode",orgCode);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        if ("yes".equals(isPage)){
            return  success(statisticalReportService.getPurchaseInwardList(mapValue));
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getPurchaseInwardList(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData4(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询该组织机构下的厂外进厂内转")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "s", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getOutFactoryInwardList")
    public RESTfulResult getOutFactoryInwardList(@RequestBody(required=false) Map<String,Object> mapValue,
                                       Integer apiId,
                                       Integer pageNum,
                                       Integer pageSize,
                                       String startTime,
                                       String endTime,
                                       String orgCode,
                                       String isPage,
                                       String index
    ){
        if (index!=null&&!"null".equals(index)){
            mapValue.put("index",index);
        }
        if (orgCode!=null&&!"null".equals(orgCode)){
            mapValue.put("orgCode",orgCode);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        if ("yes".equals(isPage)){
            return  success(statisticalReportService.getOutFactoryInwardList(mapValue));
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getOutFactoryInwardList(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData4(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询该组织机构下的内转统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "s", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getInwardInFactory")
    public RESTfulResult getInwardInFactory(@RequestBody(required=false) Map<String,Object> mapValue,
                                       Integer apiId,
                                       Integer pageNum,
                                       Integer pageSize,
                                       String startTime,
                                       String endTime,
                                       String orgCode,
                                       String isPage,
                                       String index
    ){
        if (index!=null&&!"null".equals(index)){
            mapValue.put("index",index);
        }
        if (orgCode!=null&&!"null".equals(orgCode)){
            mapValue.put("orgCode",orgCode);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        if ("yes".equals(isPage)){
            return  success(statisticalReportService.getInwardInFactory(mapValue));
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getInwardInFactory(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData4(apiId, null, report);
        return success(pageList);
    }


    @ApiOperation(value="查询拼装车统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "477", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getInwardReportForAssemble")
    public RESTfulResult getInwardReportForAssemble(@RequestBody(required=false) Map<String,Object> mapValue,
                                         Integer apiId,
                                         Integer pageNum,
                                         Integer pageSize,
                                         String startTime,
                                         String endTime, BigDecimal orderType, String index, String isPage,String orgCode
    ){
        if (index!=null&&!"null".equals(index)){
            mapValue.put("index",index);
        }
        if (orgCode!=null&&!"null".equals(orgCode)){
            mapValue.put("orgCode",orgCode);
        }
        if (orderType!=null&&!"null".equals(orderType)){
            mapValue.put("orderTypee",orderType);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        if ("yes".equals(isPage)){
            return  success(statisticalReportService.getInwardReportForAssemble(mapValue));
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getInwardReportForAssemble(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);
        return success(pageList);
    }
    @ApiOperation(value="装机展示明细")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "477", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getLoaderForResultDetail")
    public RESTfulResult getLoaderForResultDetail(@RequestBody(required=false) Map<String,Object> mapValue,
                                                    Integer apiId,
                                                    Integer pageNum,
                                                    Integer pageSize,
                                                    String startTime,
                                                    String endTime,
                                                   String con
    ){
        if (con != null && !"undefined".equals(con)) {
            mapValue.put("con",con);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getLoaderForResultDetail(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);
        return success(pageList);
    }


    @ApiOperation("对内转车辆装货点进行统计")
    @PostMapping("/getLoading")
    public RESTfulResult getLoading(@RequestBody(required=false) Map<String,Object> mapValue,
                                    Integer apiId,
                                    Integer pageNum,
                                    Integer pageSize,
                                    String startTime,
                                    String endTime){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getLoading(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);
        return success(pageList);
    }


    @ApiOperation("装载机所装车辆重量统计报表")
    @PostMapping("/getLoaderResult")
    public RESTfulResult getLoaderResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                    Integer apiId,//apiId:463
                                    Integer pageNum,
                                    Integer pageSize,
                                    String startTime,
                                    String endTime){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getLoaderResult(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation("对内转车辆装卸货点进行统计")
    @PostMapping("/getUnLoading")
    public RESTfulResult getUnLoading(@RequestBody(required=false) Map<String,Object> mapValue,
                                    Integer apiId,
                                    Integer pageNum,
                                    Integer pageSize,
                                    String startTime,
                                    String endTime){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDate);//根据时间段查询数据
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getUnLoading(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);

        return success(pageList);
    }

    //保卫部随机抽查车牌号查看所有信息
    @ApiOperation("保卫部随机抽查车牌号查看所有信息")
    @PostMapping("/getCapacityByDefend")
    public RESTfulResult getCapacityByDefend(@RequestBody(required = false) Map<String,Object> map,
                                             Integer apiId,
                                             Integer pageNum,
                                             Integer pageSize,
                                             String startTime,
                                             String endTime,
                                             String con,
                                             String yes){
        if (con != null && !"null".equals(con)) {
            map.put("con",con);
        }
        DataChange.queryDataByDateTime(startTime ,endTime, map, sdfDateTime);//根据时间段查询数据
        if(yes != null && !"null".equals(yes)){
            return success(statisticalReportService.getCapacityByDefend(map));
        }
        PageHelper.startPage(pageNum, pageSize);
        List<Map<String, Object>> report = statisticalReportService.getCapacityByDefend(map);
        PageListAdd pageList = columnDataUtil.tableColumnData4(apiId, null, report);
        return success(pageList);
    }


    @ApiOperation(value="查询销售统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(423)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getSaleSteelReport")
    public RESTfulResult getSaleSteelReport(@RequestBody(required=false) Map<String,Object> map,
                                          String startTime,
                                          String endTime,
                                          String carrierSsoId,
                                          String receiveName,
                                          String materialName,
                                          String specification,
                                          String remark,
                                          String capacityNo,
                                          String carrierName,
                                          String consigneeName,
                                          String saler
    ){
        DataChange.queryDataByDateTimeYestDay(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        if(carrierSsoId != null){
            if(!"null".equals(carrierSsoId) && carrierSsoId != null){
                map.put("carrierSsoId", carrierSsoId);
            }
        }
        if (receiveName != null && !"null".equals(receiveName)) {
            map.put("receivName","%" + receiveName + "%");
        }
        if (remark != null && !"".equals(remark) && !"null".equals(remark)) {
            map.put("remark","%" + remark + "%");
        }
        if (capacityNo != null && !"".equals(capacityNo) && !"null".equals(capacityNo)) {
            map.put("capacityNum","%" + capacityNo + "%");
        }
        if (carrierName != null && !"".equals(carrierName) && !"null".equals(carrierName)) {
            map.put("carrierNames","%" + carrierName + "%");
        }
        if (consigneeName != null && !"".equals(consigneeName) && !"null".equals(consigneeName)) {
            map.put("consigneeNames","%" + consigneeName + "%");
        }
        if (saler != null && !"".equals(saler) && !"null".equals(saler)) {
            map.put("salers",saler);
        }
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getSaleSteelReport(map);
        return success(report);
    }



    @ApiOperation(value="查询销售统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(423)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getInwardSaleSteelReport")
    public RESTfulResult getInwardSaleSteelReport(@RequestBody(required=false) Map<String,Object> map,
                                            String startTime,
                                            String endTime,
                                            String carrierSsoId,
                                            String receiveName,
                                            String materialName,
                                            String specification,
                                            String remark,
                                            String capacityNo,
                                            String carrierName,
                                            String consigneeName,
                                            String saler
    ){
        DataChange.queryDataByDateTimeYestDay(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        if(carrierSsoId != null){
            if(!"null".equals(carrierSsoId) && carrierSsoId != null){
                map.put("carrierSsoId", carrierSsoId);
            }
        }
        if (receiveName != null && !"null".equals(receiveName)) {
            map.put("receivName","%" + receiveName + "%");
        }
        if (remark != null && !"".equals(remark) && !"null".equals(remark)) {
            map.put("remark","%" + remark + "%");
        }
        if (capacityNo != null && !"".equals(capacityNo) && !"null".equals(capacityNo)) {
            map.put("capacityNum","%" + capacityNo + "%");
        }
        if (carrierName != null && !"".equals(carrierName) && !"null".equals(carrierName)) {
            map.put("carrierNames","%" + carrierName + "%");
        }
        if (consigneeName != null && !"".equals(consigneeName) && !"null".equals(consigneeName)) {
            map.put("consigneeNames","%" + consigneeName + "%");
        }
        if (saler != null && !"".equals(saler) && !"null".equals(saler)) {
            map.put("salers",saler);
        }
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getInwardSaleSteelReport(map);
        return success(report);
    }

    @ApiOperation(value="查询销售钢材派单报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(423)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getInwardSaleSteelOrder")
    public RESTfulResult getInwardSaleSteelOrder(@RequestBody(required=false) Map<String,Object> map,
                                                  String startTime,
                                                  String endTime,
                                                  String remark,
                                                  String capacityNo,
                                                  String consigneeName

    ){
        DataChange.queryDataByDateTimeYestDay(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        if (remark != null && !"".equals(remark) && !"null".equals(remark)) {
            map.put("remark","%" + remark + "%");
        }
        if (capacityNo != null && !"".equals(capacityNo) && !"null".equals(capacityNo)) {
            map.put("capacityNum","%" + capacityNo + "%");
        }
        if (consigneeName != null && !"".equals(consigneeName) && !"null".equals(consigneeName)) {
            map.put("consigneeNames","%" + consigneeName + "%");
        }
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getInwardSaleSteelOrder(map);
        return success(report);
    }
}
